@@ -3,19 +3,22 @@
  *
  * @APPLE_LICENSE_HEADER_START@
  * 
- * The contents of this file constitute Original Code as defined in and
- * are subject to the Apple Public Source License Version 1.1 (the
- * "License").	You may not use this file except in compliance with the
- * License.	 Please obtain a copy of the License at
- * http://www.apple.com/publicsource and read it before using this file.
+ * Copyright (c) 1999-2003 Apple Computer, Inc.  All Rights Reserved.
  * 
- * This Original Code and all software distributed under the License are
- * distributed on an "AS IS" basis, WITHOUT WARRANTY OF ANY KIND, EITHER
+ * This file contains Original Code and/or Modifications of Original Code
+ * as defined in and that are subject to the Apple Public Source License
+ * Version 2.0 (the 'License'). You may not use this file except in
+ * compliance with the License. Please obtain a copy of the License at
+ * http://www.opensource.apple.com/apsl/ and read it before using this
+ * file.
+ * 
+ * The Original Code and all software distributed under the License are
+ * distributed on an 'AS IS' basis, WITHOUT WARRANTY OF ANY KIND, EITHER
  * EXPRESS OR IMPLIED, AND APPLE HEREBY DISCLAIMS ALL SUCH WARRANTIES,
  * INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF MERCHANTABILITY,
- * FITNESS FOR A PARTICULAR PURPOSE OR NON-INFRINGEMENT.  Please see the
- * License for the specific language governing rights and limitations
- * under the License.
+ * FITNESS FOR A PARTICULAR PURPOSE, QUIET ENJOYMENT OR NON-INFRINGEMENT.
+ * Please see the License for the specific language governing rights and
+ * limitations under the License.
  * 
  * @APPLE_LICENSE_HEADER_END@
  */
@@ -29,6 +32,12 @@
  */
 /*
 	$Log: IOFWUserPseudoAddressSpace.cpp,v $
+	Revision 1.4.2.1  2003/07/11 03:43:53  collin
+	*** empty log message ***
+	
+	Revision 1.4  2003/04/18 20:32:06  collin
+	*** empty log message ***
+	
 	Revision 1.3  2002/10/22 00:34:25  collin
 	fix user space lock transactions, publish GUID = 0 property in objects in the IOFireWire plane
 	
@@ -247,6 +256,8 @@ IOFWUserPseudoAddressSpace::serialize(OSSerialize *s) const
 void
 IOFWUserPseudoAddressSpace::free()
 {
+	IOFWPseudoAddressSpace::free() ;
+
 	if ( fPacketQueuePrepared )
 		fPacketQueueBuffer->complete() ;
 
@@ -258,13 +269,13 @@ IOFWUserPseudoAddressSpace::free()
 
 	if ( fLastWrittenHeader )
 		delete fLastWrittenHeader ;
-
-	IOFWPseudoAddressSpace::free() ;
 }
 
 void
 IOFWUserPseudoAddressSpace::deactivate()
 {
+	IOFWPseudoAddressSpace::deactivate() ;
+
 	fBufferAvailable = 0 ;	// zzz do we need locking here to protect our data?
 	fLastReadHeader = NULL ;	
 	
@@ -287,8 +298,6 @@ IOFWUserPseudoAddressSpace::deactivate()
 		fDesc->complete() ;
 		fBackingStorePrepared = false ;
 	}
-
-	IOFWPseudoAddressSpace::deactivate() ;
 }
 
 bool
@@ -768,9 +777,15 @@ IOFWUserPseudoAddressSpace::sendPacketNotification(
 		if ( inPacketHeader->CommonHeader.type == IOFWPacketHeader::kIncomingPacket and (fFlags & kFWAddressSpaceAutoCopyOnWrite) != 0 )
 		{
 			IOByteCount len = IOFWPacketHeaderGetSize(inPacketHeader) ;
+			void * bytes = IOMalloc( len );
+		
+			fPacketQueueBuffer->readBytes( IOFWPacketHeaderGetOffset( inPacketHeader ), bytes, len );
+			
 			fDesc->writeBytes(	inPacketHeader->IncomingPacket.addrLo - fAddress.addressLo, 
-								fPacketQueueBuffer->getVirtualSegment( IOFWPacketHeaderGetOffset( inPacketHeader ), &len ),
-								IOFWPacketHeaderGetSize( inPacketHeader ) ) ;
+								bytes,
+								len ) ;
+
+			IOFree( bytes, len );
 		}
 		
 		if (inPacketHeader->CommonHeader.whichAsyncRef[0])
