@@ -3,19 +3,22 @@
  *
  * @APPLE_LICENSE_HEADER_START@
  * 
- * The contents of this file constitute Original Code as defined in and
- * are subject to the Apple Public Source License Version 1.1 (the
- * "License").  You may not use this file except in compliance with the
- * License.  Please obtain a copy of the License at
- * http://www.apple.com/publicsource and read it before using this file.
+ * Copyright (c) 1999-2003 Apple Computer, Inc.  All Rights Reserved.
  * 
- * This Original Code and all software distributed under the License are
- * distributed on an "AS IS" basis, WITHOUT WARRANTY OF ANY KIND, EITHER
+ * This file contains Original Code and/or Modifications of Original Code
+ * as defined in and that are subject to the Apple Public Source License
+ * Version 2.0 (the 'License'). You may not use this file except in
+ * compliance with the License. Please obtain a copy of the License at
+ * http://www.opensource.apple.com/apsl/ and read it before using this
+ * file.
+ * 
+ * The Original Code and all software distributed under the License are
+ * distributed on an 'AS IS' basis, WITHOUT WARRANTY OF ANY KIND, EITHER
  * EXPRESS OR IMPLIED, AND APPLE HEREBY DISCLAIMS ALL SUCH WARRANTIES,
  * INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF MERCHANTABILITY,
- * FITNESS FOR A PARTICULAR PURPOSE OR NON-INFRINGEMENT.  Please see the
- * License for the specific language governing rights and limitations
- * under the License.
+ * FITNESS FOR A PARTICULAR PURPOSE, QUIET ENJOYMENT OR NON-INFRINGEMENT.
+ * Please see the License for the specific language governing rights and
+ * limitations under the License.
  * 
  * @APPLE_LICENSE_HEADER_END@
  */
@@ -35,6 +38,52 @@ class IOFireWireROMCache;
 struct IOFWNodeScan;
 struct RomScan;
 
+class IOFireWireDevice;
+
+#pragma mark -
+
+/*! 
+	@class IOFireWireDeviceAux
+*/
+
+class IOFireWireDeviceAux : public IOFireWireNubAux
+{
+    OSDeclareDefaultStructors(IOFireWireDeviceAux)
+
+	friend class IOFireWireDevice;
+	
+protected:
+
+	bool fTerminated;
+	
+	/*! 
+		@struct ExpansionData
+		@discussion This structure will be used to expand the capablilties of the class in the future.
+    */  
+	  
+    struct ExpansionData { };
+
+	/*! 
+		@var reserved
+		Reserved for future use.  (Internal use only)  
+	*/
+    
+	ExpansionData * reserved;
+
+    virtual bool init( IOFireWireDevice * primary );
+	virtual	void free();
+
+	virtual bool isTerminated( void );
+	virtual void setTerminated( bool terminated );
+	
+private:
+    OSMetaClassDeclareReservedUnused(IOFireWireDeviceAux, 0);
+    OSMetaClassDeclareReservedUnused(IOFireWireDeviceAux, 1);
+    OSMetaClassDeclareReservedUnused(IOFireWireDeviceAux, 2);
+    OSMetaClassDeclareReservedUnused(IOFireWireDeviceAux, 3);	
+};
+
+#pragma mark -
 /*! @class IOFireWireDevice
 */
 class IOFireWireDevice : public IOFireWireNub
@@ -42,6 +91,7 @@ class IOFireWireDevice : public IOFireWireNub
     OSDeclareDefaultStructors(IOFireWireDevice)
 
     friend class IOFireWireController;
+	friend class IOFireWireDeviceAux;
 
 /*------------------Useful info about device (also available in the registry)--------*/
 protected:
@@ -137,7 +187,18 @@ protected:
 	virtual void preprocessDirectories( OSDictionary * rootPropTable, OSSet * unitSet );
 	
 	virtual void configurePhysicalFilter( void );
-	
+
+protected:
+	virtual IOFireWireNubAux * createAuxiliary( void );
+
+public:
+	inline bool isTerminated( void )
+		{ return ((IOFireWireDeviceAux*)fAuxiliary)->isTerminated(); }
+
+protected:	
+	inline void setTerminated( bool terminated )
+		{ ((IOFireWireDeviceAux*)fAuxiliary)->setTerminated( terminated ); }
+		
 private:
     OSMetaClassDeclareReservedUnused(IOFireWireDevice, 0);
     OSMetaClassDeclareReservedUnused(IOFireWireDevice, 1);
