@@ -3,19 +3,22 @@
  *
  * @APPLE_LICENSE_HEADER_START@
  * 
- * The contents of this file constitute Original Code as defined in and
- * are subject to the Apple Public Source License Version 1.1 (the
- * "License").  You may not use this file except in compliance with the
- * License.  Please obtain a copy of the License at
- * http://www.apple.com/publicsource and read it before using this file.
+ * Copyright (c) 1999-2003 Apple Computer, Inc.  All Rights Reserved.
  * 
- * This Original Code and all software distributed under the License are
- * distributed on an "AS IS" basis, WITHOUT WARRANTY OF ANY KIND, EITHER
+ * This file contains Original Code and/or Modifications of Original Code
+ * as defined in and that are subject to the Apple Public Source License
+ * Version 2.0 (the 'License'). You may not use this file except in
+ * compliance with the License. Please obtain a copy of the License at
+ * http://www.opensource.apple.com/apsl/ and read it before using this
+ * file.
+ * 
+ * The Original Code and all software distributed under the License are
+ * distributed on an 'AS IS' basis, WITHOUT WARRANTY OF ANY KIND, EITHER
  * EXPRESS OR IMPLIED, AND APPLE HEREBY DISCLAIMS ALL SUCH WARRANTIES,
  * INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF MERCHANTABILITY,
- * FITNESS FOR A PARTICULAR PURPOSE OR NON-INFRINGEMENT.  Please see the
- * License for the specific language governing rights and limitations
- * under the License.
+ * FITNESS FOR A PARTICULAR PURPOSE, QUIET ENJOYMENT OR NON-INFRINGEMENT.
+ * Please see the License for the specific language governing rights and
+ * limitations under the License.
  * 
  * @APPLE_LICENSE_HEADER_END@
  */
@@ -70,8 +73,15 @@ bool
 IOFireWireUserClientIniter::start(
 	IOService*	provider)
 {
+	if( provider == NULL )
+	{
+		return false;
+	}
+	
 	fProvider = provider ;
 
+	fProvider->retain();
+	
 	OSObject*	dictObj = getProperty("IOProviderMergeProperties");
 	
 	fProviderMergeProperties = OSDynamicCast(OSDictionary, dictObj);
@@ -123,6 +133,21 @@ IOFireWireUserClientIniter::stop(IOService* provider)
 	IOService::stop(provider) ;
 }
 
+// free
+//
+//
+
+void IOFireWireUserClientIniter::free()
+{
+	if( fProvider != NULL )
+	{
+		fProvider->release();
+		fProvider = NULL;
+	}
+	
+	IOService::free();
+}
+
 // mergeProperties
 //
 // recurively merge the properties of two dictionaries
